==> nextcloud-app-mail-4.3.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/ast.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "Mensaxes importantes",
    "No message found yet" : "Entá nun s'atopó nengún mensaxe",
    "Important" : "Importante",
    "Work" : "Trabayu",
    "Personal" : "Personal",
    "Mail" : "Corréu electrónicu",
    "Save" : "Guardar",
    "There was an error while setting up your account" : "Hebo un error mentanto se configuraba la cuenta",
    "Name" : "Nome",
    "Password" : "Contraseña",
    "Manual" : "Manual",
    "IMAP Settings" : "Configuración d'IMAP",
    "IMAP Host" : "Agospiador d'IMAP",
    "IMAP Security" : "Seguranza d'IMAP",
    "None" : "Nada",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puertu d'IMAP",
    "IMAP User" : "Usuariu d'IMAP",
    "IMAP Password" : "Contraseña d'IMAP",
    "SMTP Settings" : "Configuración de SMTP",
    "SMTP Host" : "Agospiador de SMTP",
    "SMTP Security" : "Seguranza de SMTP",
    "SMTP Port" : "Puertu de SMTP",
    "SMTP User" : "Usuariu de SMTP",
    "SMTP Password" : "Contraseña de SMTP",
    "Aliases" : "Nomatos",
    "Signature" : "Firma",
    "Default folders" : "Carpetes predeterminaes",
    "Automatic trash deletion" : "Desaniciu automáticu de la papelera",
    "Autoresponder" : "Rempuesta automática",
    "Filters" : "Filtros",
    "Mail server" : "Sirvidor de corréu electrónicu",
    "Go back" : "Dir p'atrás",
    "Change name" : "Camudar el nome",
    "Email address" : "Direición de corréu electrónicu",
    "Cancel" : "Encaboxar",
    "Accounts" : "Cuentes",
    "General" : "Xeneral",
    "List" : "Llista",
    "Vertical split" : "DIxebra verical",
    "Horizontal split" : "Dixebra horizontal",
    "Sorting" : "Orde",
    "Gravatar settings" : "Configuración de Gravatar",
    "Register" : "Rexistrase",
    "S/MIME" : "S/MIME",
    "About" : "Tocante a",
    "Keyboard shortcuts" : "Atayos del tecláu",
    "Archive" : "Archivar",
    "Delete" : "Desaniciar",
    "Search" : "Buscar",
    "Send" : "Unviar",
    "Refresh" : "Anovar",
    "Certificate updated" : "Anovóse'l certificáu",
    "Could not update certificate" : "Nun se pudo anovar el certificáu",
    "Send later" : "Unviar dempués",
    "Turn off formatting" : "Desactivar el formatu",
    "Turn off and remove formatting" : "Desactivar y quitar el formatu",
    "Keep formatting" : "Caltener el formatu",
    "From" : "De",
    "To" : "Pa",
    "Cc" : "Cc",
    "Subject" : "Asuntu",
    "Error saving draft" : "Hebo un error al guardar el borrador",
    "Draft saved" : "Guardóse'l borrador",
    "Save draft" : "Guardar el borrador",
    "Discard & close draft" : "Escartar y zarrar el borrador",
    "Enable formatting" : "Activar el formatu",
    "Disable formatting" : "Desactivar el formatu",
    "Smart picker" : "Selector intelixente",
    "Send now" : "Unviar agora",
    "Tomorrow morning" : "Mañana pela mañana",
    "Tomorrow afternoon" : "Mañana pela tarde",
    "Monday morning" : "Llunes pela mañana",
    "Enter a date" : "Introduz una data",
    "Choose" : "Escoyer",
    "Untitled message" : "Mensaxe ensin títulu",
    "Expand composer" : "Espander el compositor",
    "Close composer" : "Zarrar el compositor",
    "Confirm" : "Confirmar",
    "An error occurred, unable to delete the tag." : "Prodúxose un error, nun ye posible desaniciar la etiqueta.",
    "Plain text" : "Testu ensin formatu",
    "Rich text" : "Testu arriquecíu",
    "No messages in this mailbox" : "Nun hai nengún mensaxe nesta bandexa",
    "No messages" : "Nun hai nengún mensaxe",
    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
    "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
    "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
    "Could not delete message" : "Nun se pudo desaniciar el mensaxe",
    "Could not archive message" : "Nun se pudo archivar el mensaxe",
    "Draft: " : "Borrador:",
    "Encrypted message" : "Mensaxe cifráu",
    "This message is unread" : "Esta mensaxe ta ensin lleer",
    "Favorite" : "Meter en Favoritos",
    "Unread" : "Ensin lleer",
    "Read" : "Lleer",
    "Edit tags" : "Editar le setiquetes",
    "Move thread" : "Mover el filu",
    "Archive thread" : "Archivar el filu",
    "Delete thread" : "Desaniciar el filu",
    "More actions" : "Más aiciones",
    "Back" : "Atrás",
    "Create event" : "Crear un eventu",
    "Create task" : "Crear la xera",
    "Download message" : "Baxar el mensaxe",
    "Load more" : "Cargar más",
    "Report this bug" : "Informar d'esti fallu",
    "Event created" : "Creóse l'eventu",
    "Could not create event" : "Nun se pudo crear l'eventu",
    "All day" : "Tol día",
    "Description" : "Descripción",
    "Create" : "Crear",
    "This event was updated" : "Esti eventu anovóse",
    "{attendeeName} accepted your invitation" : "{attendeeName} aceptó la to invitación",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} aceptó provisionalmente la to invitación",
    "{attendeeName} declined your invitation" : "{attendeeName} refugó la to invitación",
    "{attendeeName} reacted to your invitation" : "{attendeeName} reaicionó a la to invitación",
    "Failed to save your participation status" : "Nun se pudo guardar l'estáu de la to participación",
    "You accepted this invitation" : "Aceptesti esta invitación",
    "You tentatively accepted this invitation" : "Aceptesti esta invitación provisionalmente",
    "You declined this invitation" : "Refuguesti esta invitación",
    "You already reacted to this invitation" : "Yá reaicionesti a esta invitación",
    "You have been invited to an event" : "Convidáronte a un eventu",
    "This event was cancelled" : "Esti eventu anulóse",
    "Select" : "Seleicionar",
    "Comment" : "Comentariu",
    "Accept" : "Aceptar",
    "Decline" : "Refugar",
    "Tentatively accept" : "Aceptar provisionalmente",
    "More options" : "Más opciones",
    "This event is in the past." : "Esti eventu ye del pasáu.",
    "individual" : "individual",
    "domain" : "dominiu",
    "Remove" : "Quitar",
    "Could not open mailbox" : "Nun se pudo abrir la bandexa de corréu",
    "Loading messages …" : "Cargando los mensaxes…",
    "No more submailboxes in here" : "Equí nun hai más sobandexes",
    "Important info" : "Información importante",
    "Forward" : "Avanzar",
    "Move message" : "Mover el mensaxe",
    "Translate" : "Traducir",
    "View source" : "Ver l'orixe",
    "Message body" : "Cuerpu del mensaxe",
    "Unnamed" : "Ensin nome",
    "Embedded message" : "Mensaxe empotráu",
    "Save to Files" : "Guardar en Ficheros",
    "Save all to Files" : "Guardar too en Ficheros",
    "The images have been blocked to protect your privacy." : "Bloquiáronse les imáxenes pa protexer la to privacidá.",
    "Show images" : "Amosar les imáxenes",
    "Show images temporarily" : "Amosar les imáxenes temporalmente",
    "Quoted text" : "Cita",
    "Move" : "Mover",
    "Loading …" : "Cargando…",
    "Not supported by the server" : "Nun ye compatible col sirvidor",
    "{usage} of {limit} used" : "{usage} de {limit} n'usu",
    "Remove account" : "Quitar la cuenta",
    "Remove {email}" : "Quitar {email}",
    "Quota" : "Cuota",
    "Add mailbox" : "Amestar una bandexa",
    "Mailbox name" : "Nome de la bandexa",
    "Saving" : "Guardando",
    "Move up" : "Xubir",
    "Move down" : "Baxar",
    "Show all mailboxes" : "Amosar toles bandexes",
    "Collapse mailboxes" : "Contrayer toles bandexes",
    "_{total} message_::_{total} messages_" : ["{total} mensaxe","{total} mensaxes"],
    "All messages in mailbox will be deleted." : "Van desaniciase tolos mensaxes d'esta bandexa.",
    "The mailbox and all messages in it will be deleted." : "Van desaniciase toles bandexes y tolos mensaxes que contengan.",
    "Delete mailbox" : "Desaniciar la bandexa",
    "Delete mailbox {name}" : "Desaniciar la bandexa «{name}»",
    "An error occurred, unable to rename the mailbox." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
    "Rename" : "Renomar",
    "Move mailbox" : "Mover la bandexa",
    "Outbox" : "Bandexa de salida",
    "New message" : "Mensaxe nuevu",
    "Edit message" : "Editar el mensaxe",
    "Draft" : "Borrador",
    "Reply" : "Responder",
    "Message saved" : "Guardóse'l mensaxe",
    "Failed to save message" : "Nun se pue guardar el mensaxe",
    "Failed to save draft" : "Nun se pue guardar el borrador",
    "Message discarded" : "Escartóse'l mensaxe",
    "Could not discard message" : "Nun se pudo escartar el mensaxe",
    "Maximize composer" : "Maximizar el compositor",
    "Minimize composer" : "Minimizar el compositor",
    "Error sending your message" : "Hebo un error al unviar el mensaxe",
    "Retry" : "Retentar",
    "Sending …" : "Unviando…",
    "Send anyway" : "Unviar de toes toes",
    "First day" : "El primer día",
    "Message" : "Mensaxe",
    "Oh Snap!" : "¡Meca!",
    "Message deleted" : "Desnaicióse'l mensaxe",
    "Copied email address to clipboard" : "La direición de corréu electrónicu copióse nel cartafueyu",
    "Could not copy email address to clipboard" : "Nun se pudo copiar la direición de corréu electrónicu nel cartafueyu",
    "Contacts with this address" : "Contautos con esta direición",
    "New Contact" : "Contautu nuevu",
    "Copy to clipboard" : "Copiar nel cartafueyu",
    "Add" : "Amestar",
    "Show less" : "Amosar menos",
    "Show more" : "Amosar más",
    "Clear" : "Borrar",
    "Close" : "Zarrar",
    "Search parameters" : "Parámetros de busca",
    "Body" : "Cuerpu",
    "Search body" : "Cuerpu de la busca",
    "Date" : "Data",
    "Pick a start date" : "Escoyer una data de comienzu",
    "Pick an end date" : "Escoyer una data de fin",
    "Tags" : "Etiquetes",
    "Select tags" : "Seleicionar etiquetes",
    "Last 7 days" : "Los últimos 7 díes",
    "Sieve Port" : "Puertu de sieve",
    "Custom" : "Personalizar",
    "Sieve User" : "Usuariu de sieve",
    "Sieve Password" : "Contraseña de sieve",
    "Save sieve settings" : "Guardar la configuración de sieve",
    "The syntax seems to be incorrect:" : "La sintaxis paez ser incorreuta",
    "Save sieve script" : "Guardar el script de sieve",
    "An error occurred, unable to rename the tag." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
    "Delete tag" : "Desaniciar la etiqueta",
    "Set tag" : "Afitar la etiqueta",
    "Unset tag" : "Quitar la etiqueta",
    "Tag already exists" : "La etiqueta yá esiste",
    "Tag name cannot be empty" : "El nome de la etiqueta nun pue tar baleru",
    "An error occurred, unable to create the tag." : "Prodúxose un error, nun ye posible crear la bandexa de corréu.",
    "Add tag" : "Amestar la etiqueta",
    "Saving tag …" : "Guardando la etiqueta…",
    "Task created" : "Creóse la xera",
    "Could not create task" : "Nun se pudo crear la xera",
    "Summarizing thread failed." : "El resume del filu falló.",
    "Could not load your message thread" : "Nun se pudo cargar el filu de mensaxes",
    "Loading thread" : "Cargando'l filu",
    "Not found" : "Nun s'atopó",
    "Archive message" : "Archivar el mensaxe",
    "Delete message" : "Desaniciar el mensaxe",
    "Message source" : "Orixe del mensaxe",
    "Go to latest message" : "Dir al últimu mensaxe",
    "Go to newest message" : "Dir al mensaxe más nuevu",
    "The message could not be translated" : "Nun se pudo traducir el mensaxe",
    "Translation copied to clipboard" : "La traducción copióse al cartafueyu",
    "Translation could not be copied" : "Nun se pudo copiar la traducción",
    "Translate message" : "Traducir el mensaxe",
    "Translating" : "Traduciendo",
    "Copy translated text" : "Copiar el testu traducíu",
    "Untitled event" : "Eventu ensin títulu",
    "Airplane" : "Avión",
    "Train" : "Tren",
    "Flag" : "Bandera",
    "Operator" : "Operador",
    "Filter name" : "Nome de la peñera",
    "Actions" : "Aiciones",
    "Priority" : "Prioridá",
    "Error saving config" : "Hebo un error al guardar la configuración",
    "Anti Spam Service" : "Serviciu de antispam",
    "Gmail integration" : "Integración con Gmail",
    "Anti Spam" : "Antispam",
    "Reset" : "Reafitar",
    "Client ID" : "ID de veceru",
    "Client secret" : "Secretu de veceru",
    "IMAP" : "IMAP",
    "User" : "Usuariu",
    "Host" : "Agospiador",
    "Port" : "Puertu",
    "SMTP" : "SMTP",
    "Master password" : "Contraseña maestra",
    "Use master password" : "Usar la contraseña maestra",
    "Sieve" : "Sieve",
    "Save Config" : "Guardar la configuración",
    "Failed to import the certificate. Please check the password." : "Nun se pue importar el certificáu. Comprueba la contraseña.",
    "Certificate imported successfully" : "El certificáu importóse correutamente",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Nun se pue importar el certificáu. Asegúrate de que la clave privada concasa cola del certificáu y nun ta protexida con una clave d'accesu.",
    "Failed to import the certificate" : "Nun se pue importar el certificáu",
    "S/MIME certificates" : "Certificaos S/MIME",
    "Certificate name" : "Nome del certificáu",
    "E-mail address" : "Direición de corréu electrónicu",
    "Delete certificate" : "Desaniciar el certificáu",
    "No certificate imported yet" : "Nun s'importó nengún certificáu",
    "Import certificate" : "Importar el certificáu",
    "PEM Certificate" : "Certificáu PEM",
    "Certificate" : "Certificáu",
    "Private key (optional)" : "Clave privada (opcional)",
    "Submit" : "Unviar",
    "Account connected" : "Conectóse la cuenta",
    "You can close this window" : "Pues zarrar esta ventana",
    "All" : "Too",
    "Drafts" : "Borradores",
    "Favorites" : "Favoritos",
    "All inboxes" : "Toles bandexes",
    "Inbox" : "Bandexa",
    "Junk" : "Puxarra",
    "Trash" : "Papelera",
    "Error while sharing file" : "Hebo un error mentanto se compartía'l ficheru",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "Nextcloud Mail",
    "Discard changes" : "Escartar los cambeos",
    "Discard unsaved changes" : "Escartar los cambeos ensin guardar",
    "Keep editing message" : "Siguir cola edición del mensaxe",
    "Message sent" : "Unvióse'l mensaxe",
    "Could not send message" : "Nun se pudo unviar el mensaxe",
    "Could not load {tag}{name}{endtag}" : "Nun se pudo cargar {tag}{name}{endtag}",
    "Could not load your message" : "Nun se pudo cargar el mensaxe",
    "Could not load the desired message" : "Nun se pudo cargar el mensaxe deseáu",
    "Could not load the message" : "Nun se pudo cargar el mensaxe",
    "Error loading message" : "Hebo un error al cargar el mensaxe",
    "Redirect" : "Redirixir",
    "The link leads to %s" : "L'enllaz lleva a %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-5.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/ast.js <==
OC.L10N.register(
    "mail",
    {
    "Important mail" : "Mensaxes importantes",
    "No message found yet" : "Entá nun s'atopó nengún mensaxe",
    "Important" : "Importante",
    "Work" : "Trabayu",
    "Personal" : "Personal",
    "Mail" : "Corréu electrónicu",
    "Save" : "Guardar",
    "There was an error while setting up your account" : "Hebo un error mentanto se configuraba la cuenta",
    "Name" : "Nome",
    "Password" : "Contraseña",
    "Manual" : "Manual",
    "IMAP Settings" : "Configuración d'IMAP",
    "IMAP Host" : "Agospiador d'IMAP",
    "IMAP Security" : "Seguranza d'IMAP",
    "None" : "Nada",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Puertu d'IMAP",
    "IMAP User" : "Usuariu d'IMAP",
    "IMAP Password" : "Contraseña d'IMAP",
    "SMTP Settings" : "Configuración de SMTP",
    "SMTP Host" : "Agospiador de SMTP",
    "SMTP Security" : "Seguranza de SMTP",
    "SMTP Port" : "Puertu de SMTP",
    "SMTP User" : "Usuariu de SMTP",
    "SMTP Password" : "Contraseña de SMTP",
    "Aliases" : "Nomatos",
    "Signature" : "Firma",
    "Default folders" : "Carpetes predeterminaes",
    "Automatic trash deletion" : "Desaniciu automáticu de la papelera",
    "Autoresponder" : "Rempuesta automática",
    "Filters" : "Filtros",
    "Mail server" : "Sirvidor de corréu electrónicu",
    "Go back" : "Dir p'atrás",
    "Change name" : "Camudar el nome",
    "Email address" : "Direición de corréu electrónicu",
    "Cancel" : "Encaboxar",
    "Accounts" : "Cuentes",
    "General" : "Xeneral",
    "List" : "Llista",
    "Vertical split" : "DIxebra verical",
    "Horizontal split" : "Dixebra horizontal",
    "Sorting" : "Orde",
    "Gravatar settings" : "Configuración de Gravatar",
    "Register" : "Rexistrase",
    "S/MIME" : "S/MIME",
    "About" : "Tocante a",
    "Keyboard shortcuts" : "Atayos del tecláu",
    "Archive" : "Archivar",
    "Delete" : "Desaniciar",
    "Search" : "Buscar",
    "Send" : "Unviar",
    "Refresh" : "Anovar",
    "Certificate updated" : "Anovóse'l certificáu",
    "Could not update certificate" : "Nun se pudo anovar el certificáu",
    "Send later" : "Unviar dempués",
    "Turn off formatting" : "Desactivar el formatu",
    "Turn off and remove formatting" : "Desactivar y quitar el formatu",
    "Keep formatting" : "Caltener el formatu",
    "From" : "De",
    "To" : "Pa",
    "Cc" : "Cc",
    "Subject" : "Asuntu",
    "Error saving draft" : "Hebo un error al guardar el borrador",
    "Draft saved" : "Guardóse'l borrador",
    "Save draft" : "Guardar el borrador",
    "Discard & close draft" : "Escartar y zarrar el borrador",
    "Enable formatting" : "Activar el formatu",
    "Disable formatting" : "Desactivar el formatu",
    "Smart picker" : "Selector intelixente",
    "Send now" : "Unviar agora",
    "Tomorrow morning" : "Mañana pela mañana",
    "Tomorrow afternoon" : "Mañana pela tarde",
    "Monday morning" : "Llunes pela mañana",
    "Enter a date" : "Introduz una data",
    "Choose" : "Escoyer",
    "Untitled message" : "Mensaxe ensin títulu",
    "Expand composer" : "Espander el compositor",
    "Close composer" : "Zarrar el compositor",
    "Confirm" : "Confirmar",
    "An error occurred, unable to delete the tag." : "Prodúxose un error, nun ye posible desaniciar la etiqueta.",
    "Plain text" : "Testu ensin formatu",
    "Rich text" : "Testu arriquecíu",
    "No messages in this mailbox" : "Nun hai nengún mensaxe nesta bandexa",
    "No messages" : "Nun hai nengún mensaxe",
    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
    "This weekend – {timeLocale}" : "Esta fin de selmana – {timeLocale}",
    "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
    "Could not delete message" : "Nun se pudo desaniciar el mensaxe",
    "Could not archive message" : "Nun se pudo archivar el mensaxe",
    "Draft: " : "Borrador:",
    "Encrypted message" : "Mensaxe cifráu",
    "This message is unread" : "Esta mensaxe ta ensin lleer",
    "Favorite" : "Meter en Favoritos",
    "Unread" : "Ensin lleer",
    "Read" : "Lleer",
    "Edit tags" : "Editar le setiquetes",
    "Move thread" : "Mover el filu",
    "Archive thread" : "Archivar el filu",
    "Delete thread" : "Desaniciar el filu",
    "More actions" : "Más aiciones",
    "Back" : "Atrás",
    "Create event" : "Crear un eventu",
    "Create task" : "Crear la xera",
    "Download message" : "Baxar el mensaxe",
    "Load more" : "Cargar más",
    "Report this bug" : "Informar d'esti fallu",
    "Event created" : "Creóse l'eventu",
    "Could not create event" : "Nun se pudo crear l'eventu",
    "All day" : "Tol día",
    "Description" : "Descripción",
    "Create" : "Crear",
    "This event was updated" : "Esti eventu anovóse",
    "{attendeeName} accepted your invitation" : "{attendeeName} aceptó la to invitación",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} aceptó provisionalmente la to invitación",
    "{attendeeName} declined your invitation" : "{attendeeName} refugó la to invitación",
    "{attendeeName} reacted to your invitation" : "{attendeeName} reaicionó a la to invitación",
    "Failed to save your participation status" : "Nun se pudo guardar l'estáu de la to participación",
    "You accepted this invitation" : "Aceptesti esta invitación",
    "You tentatively accepted this invitation" : "Aceptesti esta invitación provisionalmente",
    "You declined this invitation" : "Refuguesti esta invitación",
    "You already reacted to this invitation" : "Yá reaicionesti a esta invitación",
    "You have been invited to an event" : "Convidáronte a un eventu",
    "This event was cancelled" : "Esti eventu anulóse",
    "Select" : "Seleicionar",
    "Comment" : "Comentariu",
    "Accept" : "Aceptar",
    "Decline" : "Refugar",
    "Tentatively accept" : "Aceptar provisionalmente",
    "More options" : "Más opciones",
    "individual" : "individual",
    "domain" : "dominiu",
    "Remove" : "Quitar",
    "Could not open mailbox" : "Nun se pudo abrir la bandexa de corréu",
    "Loading messages …" : "Cargando los mensaxes…",
    "No more submailboxes in here" : "Equí nun hai más sobandexes",
    "Important info" : "Información importante",
    "Forward" : "Avanzar",
    "Move message" : "Mover el mensaxe",
    "Translate" : "Traducir",
    "View source" : "Ver l'orixe",
    "Message body" : "Cuerpu del mensaxe",
    "Unnamed" : "Ensin nome",
    "Embedded message" : "Mensaxe empotráu",
    "Save to Files" : "Guardar en Ficheros",
    "Save all to Files" : "Guardar too en Ficheros",
    "The images have been blocked to protect your privacy." : "Bloquiáronse les imáxenes pa protexer la to privacidá.",
    "Show images" : "Amosar les imáxenes",
    "Show images temporarily" : "Amosar les imáxenes temporalmente",
    "Quoted text" : "Cita",
    "Move" : "Mover",
    "Loading …" : "Cargando…",
    "Not supported by the server" : "Nun ye compatible col sirvidor",
    "{usage} of {limit} used" : "{usage} de {limit} n'usu",
    "Remove account" : "Quitar la cuenta",
    "Remove {email}" : "Quitar {email}",
    "Quota" : "Cuota",
    "Add mailbox" : "Amestar una bandexa",
    "Mailbox name" : "Nome de la bandexa",
    "Saving" : "Guardando",
    "Move up" : "Xubir",
    "Move down" : "Baxar",
    "Show all mailboxes" : "Amosar toles bandexes",
    "Collapse mailboxes" : "Contrayer toles bandexes",
    "_{total} message_::_{total} messages_" : ["{total} mensaxe","{total} mensaxes"],
    "All messages in mailbox will be deleted." : "Van desaniciase tolos mensaxes d'esta bandexa.",
    "The mailbox and all messages in it will be deleted." : "Van desaniciase toles bandexes y tolos mensaxes que contengan.",
    "Delete mailbox" : "Desaniciar la bandexa",
    "Delete mailbox {name}" : "Desaniciar la bandexa «{name}»",
    "An error occurred, unable to rename the mailbox." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
    "Rename" : "Renomar",
    "Move mailbox" : "Mover la bandexa",
    "Outbox" : "Bandexa de salida",
    "New message" : "Mensaxe nuevu",
    "Edit message" : "Editar el mensaxe",
    "Draft" : "Borrador",
    "Reply" : "Responder",
    "Message saved" : "Guardóse'l mensaxe",
    "Failed to save message" : "Nun se pue guardar el mensaxe",
    "Failed to save draft" : "Nun se pue guardar el borrador",
    "Message discarded" : "Escartóse'l mensaxe",
    "Could not discard message" : "Nun se pudo escartar el mensaxe",
    "Maximize composer" : "Maximizar el compositor",
    "Minimize composer" : "Minimizar el compositor",
    "Error sending your message" : "Hebo un error al unviar el mensaxe",
    "Retry" : "Retentar",
    "Sending …" : "Unviando…",
    "Send anyway" : "Unviar de toes toes",
    "First day" : "El primer día",
    "Message" : "Mensaxe",
    "Oh Snap!" : "¡Meca!",
    "Message deleted" : "Desnaicióse'l mensaxe",
    "Copied email address to clipboard" : "La direición de corréu electrónicu copióse nel cartafueyu",
    "Could not copy email address to clipboard" : "Nun se pudo copiar la direición de corréu electrónicu nel cartafueyu",
    "Contacts with this address" : "Contautos con esta direición",
    "New Contact" : "Contautu nuevu",
    "Copy to clipboard" : "Copiar nel cartafueyu",
    "Add" : "Amestar",
    "Show less" : "Amosar menos",
    "Show more" : "Amosar más",
    "Clear" : "Borrar",
    "Close" : "Zarrar",
    "Search parameters" : "Parámetros de busca",
    "Body" : "Cuerpu",
    "Search body" : "Cuerpu de la busca",
    "Date" : "Data",
    "Pick a start date" : "Escoyer una data de comienzu",
    "Pick an end date" : "Escoyer una data de fin",
    "Tags" : "Etiquetes",
    "Select tags" : "Seleicionar etiquetes",
    "Last 7 days" : "Los últimos 7 díes",
    "Sieve Port" : "Puertu de sieve",
    "Custom" : "Personalizar",
    "Sieve User" : "Usuariu de sieve",
    "Sieve Password" : "Contraseña de sieve",
    "Save sieve settings" : "Guardar la configuración de sieve",
    "The syntax seems to be incorrect:" : "La sintaxis paez ser incorreuta",
    "Save sieve script" : "Guardar el script de sieve",
    "An error occurred, unable to rename the tag." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
    "Delete tag" : "Desaniciar la etiqueta",
    "Set tag" : "Afitar la etiqueta",
    "Unset tag" : "Quitar la etiqueta",
    "Tag already exists" : "La etiqueta yá esiste",
    "Tag name cannot be empty" : "El nome de la etiqueta nun pue tar baleru",
    "An error occurred, unable to create the tag." : "Prodúxose un error, nun ye posible crear la bandexa de corréu.",
    "Add tag" : "Amestar la etiqueta",
    "Saving tag …" : "Guardando la etiqueta…",
    "Task created" : "Creóse la xera",
    "Could not create task" : "Nun se pudo crear la xera",
    "Summarizing thread failed." : "El resume del filu falló.",
    "Could not load your message thread" : "Nun se pudo cargar el filu de mensaxes",
    "Loading thread" : "Cargando'l filu",
    "Not found" : "Nun s'atopó",
    "Archive message" : "Archivar el mensaxe",
    "Delete message" : "Desaniciar el mensaxe",
    "Message source" : "Orixe del mensaxe",
    "Go to latest message" : "Dir al últimu mensaxe",
    "Go to newest message" : "Dir al mensaxe más nuevu",
    "The message could not be translated" : "Nun se pudo traducir el mensaxe",
    "Translation copied to clipboard" : "La traducción copióse al cartafueyu",
    "Translation could not be copied" : "Nun se pudo copiar la traducción",
    "Translate message" : "Traducir el mensaxe",
    "Translating" : "Traduciendo",
    "Copy translated text" : "Copiar el testu traducíu",
    "Untitled event" : "Eventu ensin títulu",
    "Airplane" : "Avión",
    "Train" : "Tren",
    "Flag" : "Bandera",
    "Operator" : "Operador",
    "Filter name" : "Nome de la peñera",
    "Actions" : "Aiciones",
    "Priority" : "Prioridá",
    "Error saving config" : "Hebo un error al guardar la configuración",
    "Anti Spam Service" : "Serviciu de antispam",
    "Gmail integration" : "Integración con Gmail",
    "Anti Spam" : "Antispam",
    "Reset" : "Reafitar",
    "Client ID" : "ID de veceru",
    "Client secret" : "Secretu de veceru",
    "IMAP" : "IMAP",
    "User" : "Usuariu",
    "Host" : "Agospiador",
    "Port" : "Puertu",
    "SMTP" : "SMTP",
    "Master password" : "Contraseña maestra",
    "Use master password" : "Usar la contraseña maestra",
    "Sieve" : "Sieve",
    "Save Config" : "Guardar la configuración",
    "Failed to import the certificate. Please check the password." : "Nun se pue importar el certificáu. Comprueba la contraseña.",
    "Certificate imported successfully" : "El certificáu importóse correutamente",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Nun se pue importar el certificáu. Asegúrate de que la clave privada concasa cola del certificáu y nun ta protexida con una clave d'accesu.",
    "Failed to import the certificate" : "Nun se pue importar el certificáu",
    "S/MIME certificates" : "Certificaos S/MIME",
    "Certificate name" : "Nome del certificáu",
    "E-mail address" : "Direición de corréu electrónicu",
    "Delete certificate" : "Desaniciar el certificáu",
    "No certificate imported yet" : "Nun s'importó nengún certificáu",
    "Import certificate" : "Importar el certificáu",
    "PEM Certificate" : "Certificáu PEM",
    "Certificate" : "Certificáu",
    "Private key (optional)" : "Clave privada (opcional)",
    "Submit" : "Unviar",
    "Account connected" : "Conectóse la cuenta",
    "You can close this window" : "Pues zarrar esta ventana",
    "All" : "Too",
    "Drafts" : "Borradores",
    "Favorites" : "Favoritos",
    "All inboxes" : "Toles bandexes",
    "Inbox" : "Bandexa",
    "Junk" : "Puxarra",
    "Trash" : "Papelera",
    "Error while sharing file" : "Hebo un error mentanto se compartía'l ficheru",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "Nextcloud Mail",
    "Discard changes" : "Escartar los cambeos",
    "Discard unsaved changes" : "Escartar los cambeos ensin guardar",
    "Keep editing message" : "Siguir cola edición del mensaxe",
    "Message sent" : "Unvióse'l mensaxe",
    "Could not send message" : "Nun se pudo unviar el mensaxe",
    "Could not load {tag}{name}{endtag}" : "Nun se pudo cargar {tag}{name}{endtag}",
    "Could not load your message" : "Nun se pudo cargar el mensaxe",
    "Could not load the desired message" : "Nun se pudo cargar el mensaxe deseáu",
    "Could not load the message" : "Nun se pudo cargar el mensaxe",
    "Error loading message" : "Hebo un error al cargar el mensaxe",
    "Redirect" : "Redirixir",
    "The link leads to %s" : "L'enllaz lleva a %s",
    "This event is in the past." : "Esti eventu ye del pasáu."
},
"nplurals=2; plural=(n != 1);");
